==> scute-1.0.0.tar.bz2: scute-1.0.0/tests/t-getmechanisminfo.c <==
/* t-getmechanismlist.c - Regression test.
   Copyright (C) 2006 g10 Code GmbH

   This file is part of scute[1].

   [1] Derived from the RSA Security Inc. PKCS #11 Cryptographic Token
   Interface (Cryptoki).
 
   Scute is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   Scute is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Scute; if not, write to the Free Software Foundation,
   Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

   In addition, as a special exception, g10 Code GmbH gives permission
   to link this library: with the Mozilla Foundation's code for
   Mozilla (or with modified versions of it that use the same license
   as the "Mozilla" code), and distribute the linked executables.  You
   must obey the GNU General Public License in all respects for all of
   the code used other than "Mozilla".  If you modify this file, you
   may extend this exception to your version of the file, but you are
   not obligated to do so.  If you do not wish to do so, delete this
   exception statement from your version.  */

#include <stdio.h>
#include <stdbool.h>

#include "t-support.h"


int
main (int argc, char *argv[])
{
  CK_RV err;
  CK_SLOT_ID_PTR slots;
  CK_ULONG slots_count;
  int i;

  init_cryptoki ();

  err = C_GetSlotList (true, NULL, &slots_count);
  fail_if_err (err);

  if (slots_count == 0)
    {
      printf ("Skipping test because no token is present.\n");
      return 0;
    }

  printf ("Number of slots with tokens: %lu\n", slots_count);
  slots = malloc (sizeof (CK_SLOT_ID) * slots_count);
  if (!slots)
    fail_if_err (CKR_HOST_MEMORY);

  err = C_GetSlotList (true, slots, &slots_count);
  fail_if_err (err);

  for (i = 0; i < slots_count; i++)
    {
      CK_MECHANISM_TYPE_PTR mechanisms;
      CK_ULONG mechanisms_count;
      int j;

      printf ("%2i. Slot ID %lu\n", i, slots[i]);

      err = C_GetMechanismList (slots[i], NULL, &mechanisms_count);
      fail_if_err (err);

      printf ("    Mechanisms: %lu\n", mechanisms_count);
      mechanisms = malloc (sizeof (CK_MECHANISM_TYPE) * mechanisms_count);
      if (!mechanisms)
	fail_if_err (CKR_HOST_MEMORY);

      err = C_GetMechanismList (slots[i], mechanisms, &mechanisms_count);
      fail_if_err (err);

      for (j = 0; j < mechanisms_count; j++)
	{
	  CK_MECHANISM_INFO info;

	  printf ("    %2i. %s\n", j, mechanism_type_str (mechanisms[j]));

	  err = C_GetMechanismInfo (slots[i], mechanisms[j], &info);
	  fail_if_err (err);

	  printf ("        Minimum key size: %lu\n", info.ulMinKeySize);
	  printf ("        Maximum key size: %lu\n", info.ulMaxKeySize);
	  printf ("        Flags: %#lx", info.flags);

	  if (info.flags)
	    {
	      bool any = false;
	      CK_FLAGS xflags = 0;

	      printf (" == ");
#define DO_FLAG(sym)					\
	  if (info.flags & sym)				\
	    {						\
	      printf ("%s" #sym, any ? " | " : "");	\
	      any = true;				\
              xflags |= sym;				\
	    }
	      DO_FLAG (CKF_HW);
	      DO_FLAG (CKF_ENCRYPT);
	      DO_FLAG (CKF_DECRYPT);
	      DO_FLAG (CKF_DIGEST);
	      DO_FLAG (CKF_SIGN);
	      DO_FLAG (CKF_SIGN_RECOVER);
	      DO_FLAG (CKF_VERIFY);
	      DO_FLAG (CKF_VERIFY_RECOVER);
	      DO_FLAG (CKF_GENERATE);
	      DO_FLAG (CKF_GENERATE_KEY_PAIR);
	      DO_FLAG (CKF_WRAP);
	      DO_FLAG (CKF_UNWRAP);
	      DO_FLAG (CKF_DERIVE);
	      DO_FLAG (CKF_EXTENSION);

	      xflags = info.flags & ~xflags;
	      if (xflags)
		printf ("%s%#lx", any ? " | " : "", xflags);
	    }
	  printf ("\n");
	}
      free (mechanisms);
    }

  return 0;
}

==> scute-1.1.0.tar.bz2: scute-1.1.0/tests/t-getmechanisminfo.c <==
/* t-getmechanismlist.c - Regression test.
   Copyright (C) 2006 g10 Code GmbH

   This file is part of Scute.
 
   Scute is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   Scute is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Scute; if not, write to the Free Software Foundation,
   Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

   In addition, as a special exception, g10 Code GmbH gives permission
   to link this library: with the Mozilla Foundation's code for
   Mozilla (or with modified versions of it that use the same license
   as the "Mozilla" code), and distribute the linked executables.  You
   must obey the GNU General Public License in all respects for all of
   the code used other than "Mozilla".  If you modify this file, you
   may extend this exception to your version of the file, but you are
   not obligated to do so.  If you do not wish to do so, delete this
   exception statement from your version.  */

#include <stdio.h>
#include <stdbool.h>

#include "t-support.h"


int
main (int argc, char *argv[])
{
  CK_RV err;
  CK_SLOT_ID_PTR slots;
  CK_ULONG slots_count;
  int i;

  init_cryptoki ();

  err = C_GetSlotList (true, NULL, &slots_count);
  fail_if_err (err);

  if (slots_count == 0)
    {
      printf ("Skipping test because no token is present.\n");
      return 0;
    }

  printf ("Number of slots with tokens: %lu\n", slots_count);
  slots = malloc (sizeof (CK_SLOT_ID) * slots_count);
  if (!slots)
    fail_if_err (CKR_HOST_MEMORY);

  err = C_GetSlotList (true, slots, &slots_count);
  fail_if_err (err);

  for (i = 0; i < slots_count; i++)
    {
      CK_MECHANISM_TYPE_PTR mechanisms;
      CK_ULONG mechanisms_count;
      int j;

      printf ("%2i. Slot ID %lu\n", i, slots[i]);

      err = C_GetMechanismList (slots[i], NULL, &mechanisms_count);
      fail_if_err (err);

      printf ("    Mechanisms: %lu\n", mechanisms_count);
      mechanisms = malloc (sizeof (CK_MECHANISM_TYPE) * mechanisms_count);
      if (!mechanisms)
	fail_if_err (CKR_HOST_MEMORY);

      err = C_GetMechanismList (slots[i], mechanisms, &mechanisms_count);
      fail_if_err (err);

      for (j = 0; j < mechanisms_count; j++)
	{
	  CK_MECHANISM_INFO info;

	  printf ("    %2i. %s\n", j, mechanism_type_str (mechanisms[j]));

	  err = C_GetMechanismInfo (slots[i], mechanisms[j], &info);
	  fail_if_err (err);

	  printf ("        Minimum key size: %lu\n", info.ulMinKeySize);
	  printf ("        Maximum key size: %lu\n", info.ulMaxKeySize);
	  printf ("        Flags: %#lx", info.flags);

	  if (info.flags)
	    {
	      bool any = false;
	      CK_FLAGS xflags = 0;

	      printf (" == ");
#define DO_FLAG(sym)					\
	  if (info.flags & sym)				\
	    {						\
	      printf ("%s" #sym, any ? " | " : "");	\
	      any = true;				\
              xflags |= sym;				\
	    }
	      DO_FLAG (CKF_HW);
	      DO_FLAG (CKF_ENCRYPT);
	      DO_FLAG (CKF_DECRYPT);
	      DO_FLAG (CKF_DIGEST);
	      DO_FLAG (CKF_SIGN);
	      DO_FLAG (CKF_SIGN_RECOVER);
	      DO_FLAG (CKF_VERIFY);
	      DO_FLAG (CKF_VERIFY_RECOVER);
	      DO_FLAG (CKF_GENERATE);
	      DO_FLAG (CKF_GENERATE_KEY_PAIR);
	      DO_FLAG (CKF_WRAP);
	      DO_FLAG (CKF_UNWRAP);
	      DO_FLAG (CKF_DERIVE);
	      DO_FLAG (CKF_EXTENSION);

	      xflags = info.flags & ~xflags;
	      if (xflags)
		printf ("%s%#lx", any ? " | " : "", xflags);
	    }
	  printf ("\n");
	}
      free (mechanisms);
    }

  return 0;
}
